@@ -4,7 +4,7 @@ from vidis_algorithms_api import Task
 
 class Algorithm(Task):
     def run(self, hyperspecter: np.ndarray, **kwargs) -> np.ndarray:
-        return np.zeros(hyperspecter.shape)
+        return np.zeros(hyperspecter.shape[1:])
 
     def get_type_name(self) -> str:
         """
