@@ -11,4 +11,4 @@ class CustomLayerDao:
 
     def insert_custom_layer(self, name: str, type: str, specter_id: str, params: dict):
         layer = CustomLayer.from_dict({"name": name, "type": type, "specterId": specter_id, "params": dumps(params)})
-        self.data_source.insert_layer(layer)
+        return self.data_source.insert_layer(layer)
