@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, List
 
 from pydantic import BaseModel
 
@@ -8,4 +8,4 @@ class Payload(BaseModel):
     specter_id: str
     name: str
     path: str
-    params: Optional[Dict[Any, Any]]
+    params: Dict[str, float]
