@@ -3,7 +3,7 @@ import os
 import re
 
 import numpy as np
-
+from vidis_algorithms_api.core import settings
 
 FNAME_CONTAIN_NUMBER_PATTERN = r'(\d+).npy'
 
@@ -21,7 +21,7 @@ def glob_re(pattern: str, filenames: Iterable[str]) -> Iterable[int]:
 class DataProvider:
     def __init__(self, mmap_mode: Optional[str] = 'c'):
         self.mmap_mode = mmap_mode
-        self.data_dir = os.environ.get('DATA_PATH')
+        self.data_dir = settings.DATA_PATH
 
     def get_specter(self, path: str) -> np.ndarray:
         layers = []
